Sender

Struct Sender 

pub struct Sender<T> { /* private fields */ }
Sends a value to the associated Receiver.

This is created by the channel function. Messages can be sent using send.

Implementations

Source

impl<T> Sender<T>

pub fn send(self, value: T) -> Result<(), T>

Attempts to send a value on this channel, returning it back if it could not be sent.

A successful send occurs when it is determined that the other end of the channel has not hung up already. An unsuccessful send would be one where the corresponding receiver has already been deallocated. Note that a return value of Err means that the data will never be received, but a return value of Ok does not mean that the data will be received. It is possible for the corresponding receiver to hang up immediately after this function returns Ok.

This method will never block the current thread.

Example
let (tx, rx) = sync_oneshot::channel();
std::thread::spawn(move || {
    if let Err(e) = tx.send(5) {
        println!("the receiver dropped");
    }
});

match rx.recv() {
    Ok(v) => println!("got = {:?}", v),
    Err(_) => println!("the sender dropped"),
}
pub fn is_closed(&self) -> bool

Returns true if the associated Receiver handle has been dropped.

A Receiver is closed by either calling close explicitly or the Receiver value is dropped. If true is returned, a call to send will always result in an error.